Package: haplo.stats
Version: 1.9.8.7
Date: 2026-04-24
Title: Statistical Analysis of Haplotypes with Traits and Covariates
        when Linkage Phase is Ambiguous
Authors@R: c(person("Schaid", "Daniel", role="aut"), 
             person("Jason P.", "Sinnwell", email="sinnwell.jason@mayo.edu",role=c("aut","cre")))
Description: Routines for the analysis of indirectly measured haplotypes. The statistical methods assume that all subjects are unrelated and that haplotypes are ambiguous (due to unknown linkage phase of the genetic markers). The main functions are: haplo.em(), haplo.glm(), haplo.score(), and haplo.power(); all of which have detailed examples in the vignette.
License: GPL (>= 2)
Depends: R (>= 4.4.0), methods, stats, graphics, arsenal, MASS
Suggests: knitr, testthat
VignetteBuilder: knitr
URL: https://CRAN.R-project.org/package=haplo.stats
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2026-04-24 17:29:05 UTC; sinnwell
Author: Schaid Daniel [aut],
  Jason P. Sinnwell [aut, cre]
Maintainer: Jason P. Sinnwell <sinnwell.jason@mayo.edu>
Repository: CRAN
Date/Publication: 2026-04-25 11:10:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-26 23:57:06 UTC; unix
Archs: haplo.stats.so.dSYM
