useDynLib(haplo.stats, .registration=TRUE)
importFrom("graphics", "axis", "lines", "locator", "plot", "points", "text")
importFrom("methods", "existsFunction", "setOldClass")
importFrom("stats", "anova", "binomial", "dnorm", "dpois", "formula",
           "gaussian", "glm", "glm.control", "model.extract",
           "model.matrix", "model.offset", "model.response",
           "model.weights", "na.omit", "pchisq", "pf", "pt", "qchisq",
           "qf", "qnorm", "residuals.glm", "runif", "stat.anova",
           "uniroot", "var", "weights")
import(MASS, arsenal)
export(haplo.em, summary.haplo.em, print.haplo.em, haplo.em.control)

export(haplo.score, print.haplo.score, plot.haplo.score,
       locator.haplo, score.sim.control, haplo.score.glm, haplo.score.podds)

export(haplo.score.merge, haplo.group, print.haplo.score.merge,
       print.haplo.group)

export(haplo.cc, print.haplo.cc)

export(haplo.score.slide, print.haplo.score.slide, plot.haplo.score.slide)

export(haplo.glm, summary.haplo.glm, print.haplo.glm, haplo.glm.control)

export(haplo.binomial, residuals.haplo.glm, fitted.haplo.glm, vcov.haplo.glm, anova.haplo.glm)

export(seqhap, plot.seqhap, print.seqhap)

export(haplo.scan, print.haplo.scan, haplo.scan.obs, haplo.scan.sim,
       haplo.chistat)

export(haplo.power.qt, haplo.power.qt.ncp, find.haplo.beta.qt)

export(haplo.power.cc, haplo.power.cc.ncp)

export(haplo.design, setupGeno, summaryGeno, na.geno.keep, geno1to2, Ginv,
       printBanner, geno.count.pairs, get.hapPair, locus)

S3method(print, haplo.em)
S3method(summary, haplo.em)
S3method(print, haplo.score)
S3method(plot, haplo.score)
S3method(print, haplo.group)
S3method(print, haplo.score.merge)
S3method(print, haplo.glm)
S3method(summary, haplo.glm)
S3method(residuals, haplo.glm)
S3method(fitted, haplo.glm)
S3method(anova, haplo.glm)
S3method(vcov, haplo.glm)
S3method(print, summary.haplo.glm)
S3method(print, haplo.cc)
S3method(print, haplo.score.slide)
S3method(plot, haplo.score.slide)
S3method(print, seqhap)
S3method(plot, seqhap)
S3method(print, haplo.scan)
